@@ -6,7 +6,48 @@ from . import backUpVals, restoreMethods
 
 def writeChannels(chanInfo, bak=backUpVals):
     '''
+    writeChannels(chanInfo, bak=backUpVals)
+
     Write epics channels given in a dictionary format together.
+
+    Arguments
+    ---------
+    chanInfo (dict): Channel information dictionary. See notes for format.
+    bak (dict): Dictionary of backup values during a particular instance
+                [restoreEpics.backUpVals]
+
+    Return
+    ---------
+    retDict (dict): Dictionary with keys as channel names and values as the
+                    return value of caput for that channel ie
+                    1  on succesful completion
+                    -1 or other negative value on failure of the low-level CA
+                    put.
+                    None on a failure to connect to the PV.
+
+    Notes
+    ---------
+    chanInfo dictionary minimum required format:
+    Required keys:
+      channels: Should contain dictionary with channel names as keys and their
+                values as:
+                  the value to write on teh channel
+                  or
+                  Dictionary with format:
+                  Required keys:
+                    value (any): containing value to write on channel
+                  Optional keys:
+                    tramp (float): Ramp time for change in value [None]
+                    wait (bool): whether to wait for processing to complete
+                                 [False]
+                    timeout (float): maximum time to wait for the processing to
+                                     complete [60]
+    Optional keys:
+    tramp (float): Global ramp time for change in value [None]
+    wait (bool): Global variable on whether to wait for processing to complete
+                 [False]
+    timeout (float): Global maximum time to wait for the processing to
+                     complete [60]
     '''
     # Allowing to write the value directly under channel names if no other
     # parameter is required.
@@ -18,14 +59,24 @@ def writeChannels(chanInfo, bak=backUpVals):
                 raise RuntimeError('No value found for ' + ch)
 
     discardBak = {}  # caput used in this function do not need to save backUps
-    kwargs = {'bak': discardBak}
+    kwargs = {}
     for ch in chanInfo['channels']:
-        for arg in ['wait', 'timeout']:
-            kwargs[ch] = {}
-            if arg in chanInfo:  # If present as global argument
-                kwargs[ch][arg] = chanInfo[arg]
-            elif arg in chanInfo['channels'][ch]:
-                kwargs[ch][arg] = chanInfo['channels'][ch][arg]
+        kwargs[ch] = {'bak': discardBak}
+        # If global timeout is present, use it for all channels.
+        if 'timeout' in chanInfo:
+            kwargs[ch]['timeout'] = chanInfo['timeout']
+        elif 'timeout' in chanInfo['channels'][ch]:
+            kwargs[ch]['timeout'] = chanInfo['channels'][ch]['timeout']
+        # If global wait is present
+        if 'wait' in chanInfo:
+            # If global tramp is present, individual wait should be False
+            if 'tramp' in chanInfo:
+                kwargs[ch]['wait'] = False
+            # Else, assign gloabl wait to inidivual channel arguments
+            else:
+                kwargs[ch]['wait'] = chanInfo['wait']
+        elif 'wait' in chanInfo['channels'][ch]:
+            kwargs[ch]['wait'] = chanInfo['channels'][ch]['wait']
 
     curVals = {}
     for arg in ['tramp', 'wait', 'timeout']:
@@ -45,6 +96,7 @@ def writeChannels(chanInfo, bak=backUpVals):
         bak[name] = {'type': 'group', 'value': curVals, 'sno': len(bak)}
 
     rampYourself = True
+    retDict = {}
     if 'tramp' in chanInfo:
         oldTramps = {}
         if chanInfo['tramp'] > 0:
@@ -81,9 +133,13 @@ def writeChannels(chanInfo, bak=backUpVals):
                     caput(ch, chanInfo['tramp'], bak=discardBak)
         # Write final values
         for ch in chanInfo['channels']:
-            caput(ch, chanInfo['channels'][ch]['value'], **kwargs[ch])
+            retDict[ch] = caput(ch, chanInfo['channels'][ch]['value'],
+                                **kwargs[ch])
         if not rampYourself:
-            sleep(chanInfo['tramp'])
+            # Sleep for tramp time if global wait is True
+            if 'wait' in chanInfo:
+                if chanInfo['wait']:
+                    sleep(chanInfo['tramp'])
         sleep(0.1)  # Buffer time
         for ch in oldTramps:
             caput(ch, oldTramps[ch], bak=discardBak)
@@ -91,7 +147,9 @@ def writeChannels(chanInfo, bak=backUpVals):
         for ch in chanInfo['channels']:
             if 'tramp' in chanInfo['channels'][ch]:
                 kwargs[ch]['tramp'] = chanInfo['channels'][ch]['tramp']
-            caput(ch, chanInfo['channels'][ch]['value'], **kwargs[ch])
+            retDict[ch] = caput(ch, chanInfo['channels'][ch]['value'],
+                                **kwargs[ch])
+    return retDict
 
 
 def restoreGroup(bakVal):
